🤙 Calls
========

.. image:: https://img.shields.io/pypi/v/calls.svg?style=flat-square
   :target: https://pypi.python.org/pypi/calls

.. image:: https://img.shields.io/pypi/l/calls.svg?style=flat-square
   :target: https://pypi.python.org/pypi/calls

.. image:: https://img.shields.io/pypi/pyversions/calls.svg?style=flat-square
   :target: https://pypi.python.org/pypi/calls

.. image:: https://img.shields.io/readthedocs/calls.svg?style=flat-square
   :target: http://calls.readthedocs.io/

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square
   :target: https://github.com/psf/black

Simple, typed, composable tools for callables.

Quickstart
----------

All utilities are directly importable.
See `the docs <https://calls.rtfd.io>`_ for a complete overview.

.. code-block:: python

  >>> from calls import raises, const, identity, flip

Installation
------------

It's available on PyPI.

.. code-block:: bash

  pip install calls
